@@ -12,7 +12,8 @@ import copy
 
 from collections import MutableSet, Sized, Set
 
-from ruamel.yaml.compat import ordereddict, PY2
+from ruamel.yaml.compat import ordereddict, PY2, string_types
+from ruamel.yaml.scalarstring import ScalarString
 
 if False:  # MYPY
     from typing import Any, Dict, Optional, List, Union  # NOQA
@@ -238,7 +239,7 @@ class CommentedBase(object):
         from ruamel.yaml.tokens import CommentToken
 
         def comment_token(s, mark):
-            # type: (Any) -> Any
+            # type: (Any, Any) -> Any
             # handle empty lines as having no comment
             return CommentToken(('# ' if s else '') + s + '\n', mark, None)
 
@@ -258,7 +259,7 @@ class CommentedBase(object):
             if c[3] is None:
                 c[3] = []
             for com in after.split('\n'):
-                c[3].append(comment_token(com, start_mark))
+                c[3].append(comment_token(com, start_mark))  # type: ignore
 
     @property
     def fa(self):
@@ -358,6 +359,10 @@ class CommentedBase(object):
         # type: () -> Any
         raise NotImplementedError
 
+    def _yaml_get_column(self, key):
+        # type: (Any) -> Any
+        raise NotImplementedError
+
 
 class CommentedSeq(list, CommentedBase):
     __slots__ = Comment.attrib,
@@ -388,7 +393,7 @@ class CommentedSeq(list, CommentedBase):
 
     def pop(self, idx=None):
         # type: (Any) -> Any
-        res = list.pop(self, idx)
+        res = list.pop(self, idx)  # type: ignore
         self.ca.items.pop(idx, None)  # might not be there -> default value
         for list_index in sorted(self.ca.items):
             if list_index < idx:
@@ -435,6 +440,16 @@ class CommentedSeq(list, CommentedBase):
             self.copy_attributes(res, deep=True)
         return res
 
+    def __setitem__(self, idx, value):
+        # type: (Any, Any) -> None
+        # try to preserve the scalarstring type if setting an existing key to a new value
+        if idx < len(self):
+            if isinstance(value, string_types) and \
+               not isinstance(value, ScalarString) and \
+               isinstance(self[idx], ScalarString):
+                value = type(self[idx])(value)
+        list.__setitem__(self, idx, value)
+
 
 class CommentedKeySeq(tuple, CommentedBase):
     """This primarily exists to be able to roundtrip keys that are sequences"""
@@ -684,6 +699,16 @@ class CommentedMap(ordereddict, CommentedBase):
                     return merged[1][key]
             raise
 
+    def __setitem__(self, key, value):
+        # type: (Any, Any) -> None
+        # try to preserve the scalarstring type if setting an existing key to a new value
+        if key in self:
+            if isinstance(value, string_types) and \
+               not isinstance(value, ScalarString) and \
+               isinstance(self[key], ScalarString):
+                value = type(self[key])(value)
+        ordereddict.__setitem__(self, key, value)
+
     def _unmerged_contains(self, key):
         # type: (Any) -> Any
         if ordereddict.__contains__(self, key):
